==> jc-1.4.0.tar.gz: soot/grimp/internal/GReturnStmt.h <==
// public class soot.grimp.internal.GReturnStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class e52fc4fc747af446 soot_grimp_internal_GReturnStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 7693de8bcfbb56af soot_jimple_internal_JReturnStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JReturnStmt

#include "soot/jimple/internal/JReturnStmt.h"

#ifndef _JC_soot_grimp_internal_GReturnStmt_H_
#define _JC_soot_grimp_internal_GReturnStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GReturnStmt$sub_refs	_jc_soot_grimp_internal_GReturnStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$sub_nonrefs	_jc_soot_grimp_internal_GReturnStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$refs	_jc_soot_grimp_internal_GReturnStmt$refs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$nonrefs	_jc_soot_grimp_internal_GReturnStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$object	_jc_soot_grimp_internal_GReturnStmt$object;

typedef const struct _jc_soot_grimp_internal_GReturnStmt$vmethods	_jc_soot_grimp_internal_GReturnStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GReturnStmt$vtable	_jc_soot_grimp_internal_GReturnStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GReturnStmt$vtype	_jc_soot_grimp_internal_GReturnStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GReturnStmt$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GReturnStmt$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GReturnStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GReturnStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GReturnStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GReturnStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GReturnStmt$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GReturnStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JReturnStmt$vmethods	soot_jimple_internal_JReturnStmt;
	_jc_soot_grimp_internal_GReturnStmt$vmethods	soot_grimp_internal_GReturnStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GReturnStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GReturnStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GReturnStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GReturnStmt$refs {
    _jc_soot_grimp_internal_GReturnStmt$sub_refs	soot_grimp_internal_GReturnStmt;
    _jc_soot_jimple_internal_JReturnStmt$sub_refs	soot_jimple_internal_JReturnStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GReturnStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GReturnStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JReturnStmt$sub_nonrefs	soot_jimple_internal_JReturnStmt;
    _jc_soot_grimp_internal_GReturnStmt$sub_nonrefs	soot_grimp_internal_GReturnStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GReturnStmt$object {
	_jc_soot_grimp_internal_GReturnStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GReturnStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GReturnStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GReturnStmt$vtype _jc_soot_grimp_internal_GReturnStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GReturnStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GReturnStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GReturnStmt_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GReturnStmt.h <==
// public class soot.grimp.internal.GReturnStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class e52fc4fc747af446 soot_grimp_internal_GReturnStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 7693de8bcfbb56af soot_jimple_internal_JReturnStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JReturnStmt

#include "soot/jimple/internal/JReturnStmt.h"

#ifndef _JC_soot_grimp_internal_GReturnStmt_H_
#define _JC_soot_grimp_internal_GReturnStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GReturnStmt$sub_refs	_jc_soot_grimp_internal_GReturnStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$sub_nonrefs	_jc_soot_grimp_internal_GReturnStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$refs	_jc_soot_grimp_internal_GReturnStmt$refs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$nonrefs	_jc_soot_grimp_internal_GReturnStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GReturnStmt$object	_jc_soot_grimp_internal_GReturnStmt$object;

typedef const struct _jc_soot_grimp_internal_GReturnStmt$vmethods	_jc_soot_grimp_internal_GReturnStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GReturnStmt$vtable	_jc_soot_grimp_internal_GReturnStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GReturnStmt$vtype	_jc_soot_grimp_internal_GReturnStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GReturnStmt$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GReturnStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GReturnStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GReturnStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GReturnStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GReturnStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GReturnStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GReturnStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JReturnStmt$vmethods	soot_jimple_internal_JReturnStmt;
	_jc_soot_grimp_internal_GReturnStmt$vmethods	soot_grimp_internal_GReturnStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GReturnStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GReturnStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GReturnStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GReturnStmt$refs {
    _jc_soot_grimp_internal_GReturnStmt$sub_refs	soot_grimp_internal_GReturnStmt;
    _jc_soot_jimple_internal_JReturnStmt$sub_refs	soot_jimple_internal_JReturnStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GReturnStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GReturnStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JReturnStmt$sub_nonrefs	soot_jimple_internal_JReturnStmt;
    _jc_soot_grimp_internal_GReturnStmt$sub_nonrefs	soot_grimp_internal_GReturnStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GReturnStmt$object {
	_jc_soot_grimp_internal_GReturnStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GReturnStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GReturnStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GReturnStmt$vtype _jc_soot_grimp_internal_GReturnStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GReturnStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GReturnStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GReturnStmt_H_ */
